pub fn extract_request<R: Request>(envelope: Envelope) -> (R, ResponseToken<R>)Expand description
Extracts request message with the provided type from Envelope, panics
otherwise.
pub fn extract_request<R: Request>(envelope: Envelope) -> (R, ResponseToken<R>)Extracts request message with the provided type from Envelope, panics
otherwise.