pub async fn proxy(
blueprint: Blueprint,
config: impl for<'de> Deserializer<'de>,
) -> ProxyExpand description
Creates a proxy for testing actors. See examples in the repository for more details how to use it.
pub async fn proxy(
blueprint: Blueprint,
config: impl for<'de> Deserializer<'de>,
) -> ProxyCreates a proxy for testing actors. See examples in the repository for more details how to use it.