Proxy

Struct Proxy 

pub struct Proxy { /* private fields */ }
A proxy for testing actors.

Implementations

Source

impl Proxy

pub fn addr(&self) -> Addr

Returns an address of the proxy.

pub fn node_launch_id(&self) -> NodeLaunchId

Returns a launch ID of the topology.

It can be used to distinguish produced artifacts (logs, dumps, metrics) from different concurrent tests if the custom implementation is used.

pub fn unbounded_send<M: Message>(&self, message: M)

See Context::unbounded_send() for details.

pub fn unbounded_send_to<M: Message>(&self, recipient: Addr, message: M)

pub fn send<M: Message>(&self, message: M) -> impl Future<Output = ()> + '_

See Context::send() for details.

pub fn send_to<M: Message>( &self, recipient: Addr, message: M, ) -> impl Future<Output = ()> + '_

See Context::send_to() for details.

pub fn try_send<M: Message>(&self, message: M) -> Result<(), TrySendError<M>>

See Context::try_send() for details.

pub fn try_send_to<M: Message>( &self, recipient: Addr, message: M, ) -> Result<(), TrySendError<M>>

See Context::try_send_to() for details.

pub fn request_fallible<R: Request>( &self, request: R, ) -> impl Future<Output = Result<R::Response, RequestError>>

Same as Self::request, but doesn’t unwraps the error.

pub fn request<R: Request>( &self, request: R, ) -> impl Future<Output = R::Response>

See Context::request() for details.

pub fn request_to_fallible<R: Request>( &self, recipient: Addr, request: R, ) -> impl Future<Output = Result<R::Response, RequestError>>

Same as Self::request_to, but doesn’t unwraps the errors.

pub fn request_to<R: Request>( &self, recipient: Addr, request: R, ) -> impl Future<Output = R::Response>

See Context::request_to() for details.

pub fn respond<R: Request>( &self, token: ResponseToken<R>, response: R::Response, )

See Context::respond() for details.

pub fn recv(&mut self) -> impl Future<Output = Envelope> + '_

See Context::recv() for details.

pub async fn try_recv(&mut self) -> Option<Envelope>

See Context::try_recv() for details.

pub async fn sync(&mut self)

Waits until the testable actor handles all previously sent messages.

Now it’s implemented as multiple calls yield_now(), but the implementation can be changed in the future.

pub fn set_recv_timeout(&mut self, recv_timeout: Duration)

Sets message wait time for recv call.

pub async fn subproxy(&self) -> Proxy

Creates a subproxy with a different address. The main purpose is to test send_to(..) and request_to(..) calls.

pub async fn finished(&self)

Waits until the testable actor finishes.

pub fn close(&self)

Closes a mailbox of the proxy.