pub struct Proxy { /* private fields */ }

Implementations

Waits until the testable actor handles all previously sent messages.

Now it’s implemented as multiple calls yield_now(), but the implementation can be changed in the future.

👎Deprecated

Sets message wait time for recv call.

Creates a subproxy with a different address. The main purpose is to test send_to(..) and request(..).from(..) calls. It’s likely to be changed in the future.

Closes a mailbox of the proxy.