pub struct Proxy { /* fields omitted */ }
Waits until the testable actor handles all previously sent messages.
Now it’s implemented as multiple calls yield_now(),
but the implementation can be changed in the future.
Creates a subproxy with a different address.
The main purpose is to test send_to(..) and request(..).from(..)
calls. It’s likely to be changed in the future.
Executes the destructor for this type. Read more
impl<T> Any for T where
T: 'static + ?Sized,
Immutably borrows from an owned value. Read more
Mutably borrows from an owned value. Read more
Instruments this type with the provided Span, returning an
Instrumented wrapper. Read more
Instruments this type with the current Span, returning an
Instrumented wrapper. Read more
impl<T, U> Into<U> for T where
U: From<T>,
The type returned in the event of a conversion error.
The type returned in the event of a conversion error.